"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from documenso_sdk.utils import FieldMetadata, PathParamMetadata
from enum import Enum
import httpx
import pydantic
from pydantic import model_serializer
from typing import Any, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class FieldGetDocumentFieldRequestTypedDict(TypedDict):
    field_id: float


class FieldGetDocumentFieldRequest(BaseModel):
    field_id: Annotated[
        float,
        pydantic.Field(alias="fieldId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class FieldGetDocumentFieldInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class FieldGetDocumentFieldInternalServerErrorIssue(BaseModel):
    message: str


class FieldGetDocumentFieldInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldGetDocumentFieldInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class FieldGetDocumentFieldInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: FieldGetDocumentFieldInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldGetDocumentFieldInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldGetDocumentFieldNotFoundIssueTypedDict(TypedDict):
    message: str


class FieldGetDocumentFieldNotFoundIssue(BaseModel):
    message: str


class FieldGetDocumentFieldNotFoundErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldGetDocumentFieldNotFoundIssue]] = None


@dataclass(unsafe_hash=True)
class FieldGetDocumentFieldNotFoundError(DocumensoError):
    r"""Not found"""

    data: FieldGetDocumentFieldNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldGetDocumentFieldNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldGetDocumentFieldForbiddenIssueTypedDict(TypedDict):
    message: str


class FieldGetDocumentFieldForbiddenIssue(BaseModel):
    message: str


class FieldGetDocumentFieldForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldGetDocumentFieldForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class FieldGetDocumentFieldForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: FieldGetDocumentFieldForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldGetDocumentFieldForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldGetDocumentFieldUnauthorizedIssueTypedDict(TypedDict):
    message: str


class FieldGetDocumentFieldUnauthorizedIssue(BaseModel):
    message: str


class FieldGetDocumentFieldUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldGetDocumentFieldUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class FieldGetDocumentFieldUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: FieldGetDocumentFieldUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldGetDocumentFieldUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldGetDocumentFieldBadRequestIssueTypedDict(TypedDict):
    message: str


class FieldGetDocumentFieldBadRequestIssue(BaseModel):
    message: str


class FieldGetDocumentFieldBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldGetDocumentFieldBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class FieldGetDocumentFieldBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: FieldGetDocumentFieldBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldGetDocumentFieldBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldGetDocumentFieldType(str, Enum):
    SIGNATURE = "SIGNATURE"
    FREE_SIGNATURE = "FREE_SIGNATURE"
    INITIALS = "INITIALS"
    NAME = "NAME"
    EMAIL = "EMAIL"
    DATE = "DATE"
    TEXT = "TEXT"
    NUMBER = "NUMBER"
    RADIO = "RADIO"
    CHECKBOX = "CHECKBOX"
    DROPDOWN = "DROPDOWN"


class FieldGetDocumentFieldTypeDropdown(str, Enum):
    DROPDOWN = "dropdown"


class FieldGetDocumentFieldValue3TypedDict(TypedDict):
    value: str


class FieldGetDocumentFieldValue3(BaseModel):
    value: str


class FieldGetDocumentFieldFieldMetaDropdownTypedDict(TypedDict):
    type: FieldGetDocumentFieldTypeDropdown
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldGetDocumentFieldValue3TypedDict]]
    default_value: NotRequired[str]


class FieldGetDocumentFieldFieldMetaDropdown(BaseModel):
    type: FieldGetDocumentFieldTypeDropdown

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldGetDocumentFieldValue3]] = None

    default_value: Annotated[Optional[str], pydantic.Field(alias="defaultValue")] = None


class FieldGetDocumentFieldTypeCheckbox(str, Enum):
    CHECKBOX = "checkbox"


class FieldGetDocumentFieldValue2TypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class FieldGetDocumentFieldValue2(BaseModel):
    id: float

    checked: bool

    value: str


class FieldGetDocumentFieldDirection2(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class FieldGetDocumentFieldFieldMetaCheckboxTypedDict(TypedDict):
    type: FieldGetDocumentFieldTypeCheckbox
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldGetDocumentFieldValue2TypedDict]]
    validation_rule: NotRequired[str]
    validation_length: NotRequired[float]
    direction: NotRequired[FieldGetDocumentFieldDirection2]


class FieldGetDocumentFieldFieldMetaCheckbox(BaseModel):
    type: FieldGetDocumentFieldTypeCheckbox

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldGetDocumentFieldValue2]] = None

    validation_rule: Annotated[
        Optional[str], pydantic.Field(alias="validationRule")
    ] = None

    validation_length: Annotated[
        Optional[float], pydantic.Field(alias="validationLength")
    ] = None

    direction: Optional[FieldGetDocumentFieldDirection2] = (
        FieldGetDocumentFieldDirection2.VERTICAL
    )


class FieldGetDocumentFieldTypeRadio(str, Enum):
    RADIO = "radio"


class FieldGetDocumentFieldValue1TypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class FieldGetDocumentFieldValue1(BaseModel):
    id: float

    checked: bool

    value: str


class FieldGetDocumentFieldDirection1(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class FieldGetDocumentFieldFieldMetaRadioTypedDict(TypedDict):
    type: FieldGetDocumentFieldTypeRadio
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldGetDocumentFieldValue1TypedDict]]
    direction: NotRequired[FieldGetDocumentFieldDirection1]


class FieldGetDocumentFieldFieldMetaRadio(BaseModel):
    type: FieldGetDocumentFieldTypeRadio

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldGetDocumentFieldValue1]] = None

    direction: Optional[FieldGetDocumentFieldDirection1] = (
        FieldGetDocumentFieldDirection1.VERTICAL
    )


class FieldGetDocumentFieldTypeNumber(str, Enum):
    NUMBER = "number"


class FieldGetDocumentFieldTextAlign6(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldGetDocumentFieldVerticalAlign2(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class FieldGetDocumentFieldFieldMetaNumberTypedDict(TypedDict):
    type: FieldGetDocumentFieldTypeNumber
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    number_format: NotRequired[Nullable[str]]
    value: NotRequired[str]
    min_value: NotRequired[Nullable[float]]
    max_value: NotRequired[Nullable[float]]
    text_align: NotRequired[FieldGetDocumentFieldTextAlign6]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[Nullable[FieldGetDocumentFieldVerticalAlign2]]


class FieldGetDocumentFieldFieldMetaNumber(BaseModel):
    type: FieldGetDocumentFieldTypeNumber

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    number_format: Annotated[
        OptionalNullable[str], pydantic.Field(alias="numberFormat")
    ] = UNSET

    value: Optional[str] = None

    min_value: Annotated[OptionalNullable[float], pydantic.Field(alias="minValue")] = (
        UNSET
    )

    max_value: Annotated[OptionalNullable[float], pydantic.Field(alias="maxValue")] = (
        UNSET
    )

    text_align: Annotated[
        Optional[FieldGetDocumentFieldTextAlign6], pydantic.Field(alias="textAlign")
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[FieldGetDocumentFieldVerticalAlign2],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "numberFormat",
            "value",
            "minValue",
            "maxValue",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = [
            "numberFormat",
            "minValue",
            "maxValue",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class FieldGetDocumentFieldTypeText(str, Enum):
    TEXT = "text"


class FieldGetDocumentFieldTextAlign5(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldGetDocumentFieldVerticalAlign1(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class FieldGetDocumentFieldFieldMetaTextTypedDict(TypedDict):
    type: FieldGetDocumentFieldTypeText
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text: NotRequired[str]
    character_limit: NotRequired[float]
    text_align: NotRequired[FieldGetDocumentFieldTextAlign5]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[Nullable[FieldGetDocumentFieldVerticalAlign1]]


class FieldGetDocumentFieldFieldMetaText(BaseModel):
    type: FieldGetDocumentFieldTypeText

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text: Optional[str] = None

    character_limit: Annotated[
        Optional[float], pydantic.Field(alias="characterLimit")
    ] = None

    text_align: Annotated[
        Optional[FieldGetDocumentFieldTextAlign5], pydantic.Field(alias="textAlign")
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[FieldGetDocumentFieldVerticalAlign1],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "text",
            "characterLimit",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = ["lineHeight", "letterSpacing", "verticalAlign"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class FieldGetDocumentFieldTypeDate(str, Enum):
    DATE = "date"


class FieldGetDocumentFieldTextAlign4(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldGetDocumentFieldFieldMetaDateTypedDict(TypedDict):
    type: FieldGetDocumentFieldTypeDate
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldGetDocumentFieldTextAlign4]


class FieldGetDocumentFieldFieldMetaDate(BaseModel):
    type: FieldGetDocumentFieldTypeDate

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldGetDocumentFieldTextAlign4], pydantic.Field(alias="textAlign")
    ] = None


class FieldGetDocumentFieldTypeEmail(str, Enum):
    EMAIL = "email"


class FieldGetDocumentFieldTextAlign3(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldGetDocumentFieldFieldMetaEmailTypedDict(TypedDict):
    type: FieldGetDocumentFieldTypeEmail
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldGetDocumentFieldTextAlign3]


class FieldGetDocumentFieldFieldMetaEmail(BaseModel):
    type: FieldGetDocumentFieldTypeEmail

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldGetDocumentFieldTextAlign3], pydantic.Field(alias="textAlign")
    ] = None


class FieldGetDocumentFieldTypeName(str, Enum):
    NAME = "name"


class FieldGetDocumentFieldTextAlign2(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldGetDocumentFieldFieldMetaNameTypedDict(TypedDict):
    type: FieldGetDocumentFieldTypeName
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldGetDocumentFieldTextAlign2]


class FieldGetDocumentFieldFieldMetaName(BaseModel):
    type: FieldGetDocumentFieldTypeName

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldGetDocumentFieldTextAlign2], pydantic.Field(alias="textAlign")
    ] = None


class FieldGetDocumentFieldTypeInitials(str, Enum):
    INITIALS = "initials"


class FieldGetDocumentFieldTextAlign1(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldGetDocumentFieldFieldMetaInitialsTypedDict(TypedDict):
    type: FieldGetDocumentFieldTypeInitials
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldGetDocumentFieldTextAlign1]


class FieldGetDocumentFieldFieldMetaInitials(BaseModel):
    type: FieldGetDocumentFieldTypeInitials

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldGetDocumentFieldTextAlign1], pydantic.Field(alias="textAlign")
    ] = None


class FieldGetDocumentFieldTypeSignature(str, Enum):
    SIGNATURE = "signature"


class FieldGetDocumentFieldFieldMetaSignatureTypedDict(TypedDict):
    type: FieldGetDocumentFieldTypeSignature
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]


class FieldGetDocumentFieldFieldMetaSignature(BaseModel):
    type: FieldGetDocumentFieldTypeSignature

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12


FieldGetDocumentFieldFieldMetaUnionTypedDict = TypeAliasType(
    "FieldGetDocumentFieldFieldMetaUnionTypedDict",
    Union[
        FieldGetDocumentFieldFieldMetaSignatureTypedDict,
        FieldGetDocumentFieldFieldMetaInitialsTypedDict,
        FieldGetDocumentFieldFieldMetaNameTypedDict,
        FieldGetDocumentFieldFieldMetaEmailTypedDict,
        FieldGetDocumentFieldFieldMetaDateTypedDict,
        FieldGetDocumentFieldFieldMetaRadioTypedDict,
        FieldGetDocumentFieldFieldMetaDropdownTypedDict,
        FieldGetDocumentFieldFieldMetaCheckboxTypedDict,
        FieldGetDocumentFieldFieldMetaTextTypedDict,
        FieldGetDocumentFieldFieldMetaNumberTypedDict,
    ],
)


FieldGetDocumentFieldFieldMetaUnion = TypeAliasType(
    "FieldGetDocumentFieldFieldMetaUnion",
    Union[
        FieldGetDocumentFieldFieldMetaSignature,
        FieldGetDocumentFieldFieldMetaInitials,
        FieldGetDocumentFieldFieldMetaName,
        FieldGetDocumentFieldFieldMetaEmail,
        FieldGetDocumentFieldFieldMetaDate,
        FieldGetDocumentFieldFieldMetaRadio,
        FieldGetDocumentFieldFieldMetaDropdown,
        FieldGetDocumentFieldFieldMetaCheckbox,
        FieldGetDocumentFieldFieldMetaText,
        FieldGetDocumentFieldFieldMetaNumber,
    ],
)


class FieldGetDocumentFieldResponseTypedDict(TypedDict):
    r"""Successful response"""

    envelope_id: str
    envelope_item_id: str
    type: FieldGetDocumentFieldType
    id: float
    secondary_id: str
    recipient_id: float
    page: float
    position_x: Any
    position_y: Any
    width: Any
    height: Any
    custom_text: str
    inserted: bool
    field_meta: Nullable[FieldGetDocumentFieldFieldMetaUnionTypedDict]
    document_id: NotRequired[Nullable[float]]
    template_id: NotRequired[Nullable[float]]


class FieldGetDocumentFieldResponse(BaseModel):
    r"""Successful response"""

    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    envelope_item_id: Annotated[str, pydantic.Field(alias="envelopeItemId")]

    type: FieldGetDocumentFieldType

    id: float

    secondary_id: Annotated[str, pydantic.Field(alias="secondaryId")]

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page: float

    position_x: Annotated[Any, pydantic.Field(alias="positionX")]

    position_y: Annotated[Any, pydantic.Field(alias="positionY")]

    width: Any

    height: Any

    custom_text: Annotated[str, pydantic.Field(alias="customText")]

    inserted: bool

    field_meta: Annotated[
        Nullable[FieldGetDocumentFieldFieldMetaUnion], pydantic.Field(alias="fieldMeta")
    ]

    document_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="documentId")
    ] = UNSET

    template_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="templateId")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["documentId", "templateId"]
        nullable_fields = ["fieldMeta", "documentId", "templateId"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from documenso_sdk.utils import FieldMetadata, QueryParamMetadata
from enum import Enum
import httpx
import pydantic
from pydantic import model_serializer
from typing import Dict, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class QueryParamSource(str, Enum):
    r"""Filter documents by how it was created."""

    DOCUMENT = "DOCUMENT"
    TEMPLATE = "TEMPLATE"
    TEMPLATE_DIRECT_LINK = "TEMPLATE_DIRECT_LINK"


class QueryParamStatus(str, Enum):
    r"""Filter documents by the current status"""

    DRAFT = "DRAFT"
    PENDING = "PENDING"
    COMPLETED = "COMPLETED"
    REJECTED = "REJECTED"


class OrderByColumn(str, Enum):
    CREATED_AT = "createdAt"


class OrderByDirection(str, Enum):
    ASC = "asc"
    DESC = "desc"


class DocumentFindRequestTypedDict(TypedDict):
    query: NotRequired[str]
    r"""The search query."""
    page: NotRequired[float]
    r"""The pagination page number, starts at 1."""
    per_page: NotRequired[float]
    r"""The number of items per page."""
    template_id: NotRequired[float]
    r"""Filter documents by the template ID used to create it."""
    source: NotRequired[QueryParamSource]
    r"""Filter documents by how it was created."""
    status: NotRequired[QueryParamStatus]
    r"""Filter documents by the current status"""
    folder_id: NotRequired[str]
    r"""Filter documents by folder ID"""
    order_by_column: NotRequired[OrderByColumn]
    order_by_direction: NotRequired[OrderByDirection]


class DocumentFindRequest(BaseModel):
    query: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""The search query."""

    page: Annotated[
        Optional[float],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""The pagination page number, starts at 1."""

    per_page: Annotated[
        Optional[float],
        pydantic.Field(alias="perPage"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""The number of items per page."""

    template_id: Annotated[
        Optional[float],
        pydantic.Field(alias="templateId"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Filter documents by the template ID used to create it."""

    source: Annotated[
        Optional[QueryParamSource],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Filter documents by how it was created."""

    status: Annotated[
        Optional[QueryParamStatus],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Filter documents by the current status"""

    folder_id: Annotated[
        Optional[str],
        pydantic.Field(alias="folderId"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Filter documents by folder ID"""

    order_by_column: Annotated[
        Optional[OrderByColumn],
        pydantic.Field(alias="orderByColumn"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None

    order_by_direction: Annotated[
        Optional[OrderByDirection],
        pydantic.Field(alias="orderByDirection"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = OrderByDirection.DESC


class DocumentFindInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class DocumentFindInternalServerErrorIssue(BaseModel):
    message: str


class DocumentFindInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentFindInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentFindInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: DocumentFindInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentFindInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentFindNotFoundIssueTypedDict(TypedDict):
    message: str


class DocumentFindNotFoundIssue(BaseModel):
    message: str


class DocumentFindNotFoundErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentFindNotFoundIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentFindNotFoundError(DocumensoError):
    r"""Not found"""

    data: DocumentFindNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentFindNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentFindForbiddenIssueTypedDict(TypedDict):
    message: str


class DocumentFindForbiddenIssue(BaseModel):
    message: str


class DocumentFindForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentFindForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentFindForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: DocumentFindForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentFindForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentFindUnauthorizedIssueTypedDict(TypedDict):
    message: str


class DocumentFindUnauthorizedIssue(BaseModel):
    message: str


class DocumentFindUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentFindUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentFindUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: DocumentFindUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentFindUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentFindBadRequestIssueTypedDict(TypedDict):
    message: str


class DocumentFindBadRequestIssue(BaseModel):
    message: str


class DocumentFindBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentFindBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentFindBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: DocumentFindBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentFindBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentFindVisibility(str, Enum):
    EVERYONE = "EVERYONE"
    MANAGER_AND_ABOVE = "MANAGER_AND_ABOVE"
    ADMIN = "ADMIN"


class DataStatus(str, Enum):
    DRAFT = "DRAFT"
    PENDING = "PENDING"
    COMPLETED = "COMPLETED"
    REJECTED = "REJECTED"


class DataSource(str, Enum):
    DOCUMENT = "DOCUMENT"
    TEMPLATE = "TEMPLATE"
    TEMPLATE_DIRECT_LINK = "TEMPLATE_DIRECT_LINK"


class DocumentFindGlobalAccessAuth(str, Enum):
    ACCOUNT = "ACCOUNT"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"


class DocumentFindGlobalActionAuth(str, Enum):
    ACCOUNT = "ACCOUNT"
    PASSKEY = "PASSKEY"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"
    PASSWORD = "PASSWORD"


class DocumentFindAuthOptionsTypedDict(TypedDict):
    global_access_auth: List[DocumentFindGlobalAccessAuth]
    global_action_auth: List[DocumentFindGlobalActionAuth]


class DocumentFindAuthOptions(BaseModel):
    global_access_auth: Annotated[
        List[DocumentFindGlobalAccessAuth], pydantic.Field(alias="globalAccessAuth")
    ]

    global_action_auth: Annotated[
        List[DocumentFindGlobalActionAuth], pydantic.Field(alias="globalActionAuth")
    ]


DocumentFindFormValuesTypedDict = TypeAliasType(
    "DocumentFindFormValuesTypedDict", Union[str, bool, float]
)


DocumentFindFormValues = TypeAliasType(
    "DocumentFindFormValues", Union[str, bool, float]
)


class DocumentFindUserTypedDict(TypedDict):
    id: float
    name: Nullable[str]
    email: str


class DocumentFindUser(BaseModel):
    id: float

    name: Nullable[str]

    email: str

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["name"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class DocumentFindRole(str, Enum):
    CC = "CC"
    SIGNER = "SIGNER"
    VIEWER = "VIEWER"
    APPROVER = "APPROVER"
    ASSISTANT = "ASSISTANT"


class DocumentFindReadStatus(str, Enum):
    NOT_OPENED = "NOT_OPENED"
    OPENED = "OPENED"


class DocumentFindSigningStatus(str, Enum):
    NOT_SIGNED = "NOT_SIGNED"
    SIGNED = "SIGNED"
    REJECTED = "REJECTED"


class DocumentFindSendStatus(str, Enum):
    NOT_SENT = "NOT_SENT"
    SENT = "SENT"


class DocumentFindAccessAuth(str, Enum):
    ACCOUNT = "ACCOUNT"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"


class DocumentFindActionAuth(str, Enum):
    ACCOUNT = "ACCOUNT"
    PASSKEY = "PASSKEY"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"
    PASSWORD = "PASSWORD"
    EXPLICIT_NONE = "EXPLICIT_NONE"


class DocumentFindRecipientAuthOptionsTypedDict(TypedDict):
    access_auth: List[DocumentFindAccessAuth]
    action_auth: List[DocumentFindActionAuth]


class DocumentFindRecipientAuthOptions(BaseModel):
    access_auth: Annotated[
        List[DocumentFindAccessAuth], pydantic.Field(alias="accessAuth")
    ]

    action_auth: Annotated[
        List[DocumentFindActionAuth], pydantic.Field(alias="actionAuth")
    ]


class DocumentFindRecipientTypedDict(TypedDict):
    envelope_id: str
    role: DocumentFindRole
    read_status: DocumentFindReadStatus
    signing_status: DocumentFindSigningStatus
    send_status: DocumentFindSendStatus
    id: float
    email: str
    name: str
    token: str
    document_deleted_at: Nullable[str]
    expired: Nullable[str]
    signed_at: Nullable[str]
    auth_options: Nullable[DocumentFindRecipientAuthOptionsTypedDict]
    signing_order: Nullable[float]
    rejection_reason: Nullable[str]
    document_id: NotRequired[Nullable[float]]
    template_id: NotRequired[Nullable[float]]


class DocumentFindRecipient(BaseModel):
    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    role: DocumentFindRole

    read_status: Annotated[DocumentFindReadStatus, pydantic.Field(alias="readStatus")]

    signing_status: Annotated[
        DocumentFindSigningStatus, pydantic.Field(alias="signingStatus")
    ]

    send_status: Annotated[DocumentFindSendStatus, pydantic.Field(alias="sendStatus")]

    id: float

    email: str

    name: str

    token: str

    document_deleted_at: Annotated[
        Nullable[str], pydantic.Field(alias="documentDeletedAt")
    ]

    expired: Nullable[str]

    signed_at: Annotated[Nullable[str], pydantic.Field(alias="signedAt")]

    auth_options: Annotated[
        Nullable[DocumentFindRecipientAuthOptions], pydantic.Field(alias="authOptions")
    ]

    signing_order: Annotated[Nullable[float], pydantic.Field(alias="signingOrder")]

    rejection_reason: Annotated[Nullable[str], pydantic.Field(alias="rejectionReason")]

    document_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="documentId")
    ] = UNSET

    template_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="templateId")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["documentId", "templateId"]
        nullable_fields = [
            "documentDeletedAt",
            "expired",
            "signedAt",
            "authOptions",
            "signingOrder",
            "rejectionReason",
            "documentId",
            "templateId",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class DocumentFindTeamTypedDict(TypedDict):
    id: float
    url: str


class DocumentFindTeam(BaseModel):
    id: float

    url: str


class DocumentFindDataTypedDict(TypedDict):
    visibility: DocumentFindVisibility
    status: DataStatus
    source: DataSource
    id: float
    external_id: Nullable[str]
    user_id: float
    auth_options: Nullable[DocumentFindAuthOptionsTypedDict]
    form_values: Nullable[Dict[str, DocumentFindFormValuesTypedDict]]
    title: str
    created_at: str
    updated_at: str
    completed_at: Nullable[str]
    deleted_at: Nullable[str]
    team_id: float
    folder_id: Nullable[str]
    use_legacy_field_insertion: bool
    envelope_id: str
    internal_version: float
    user: DocumentFindUserTypedDict
    recipients: List[DocumentFindRecipientTypedDict]
    team: Nullable[DocumentFindTeamTypedDict]
    document_data_id: NotRequired[str]
    template_id: NotRequired[Nullable[float]]


class DocumentFindData(BaseModel):
    visibility: DocumentFindVisibility

    status: DataStatus

    source: DataSource

    id: float

    external_id: Annotated[Nullable[str], pydantic.Field(alias="externalId")]

    user_id: Annotated[float, pydantic.Field(alias="userId")]

    auth_options: Annotated[
        Nullable[DocumentFindAuthOptions], pydantic.Field(alias="authOptions")
    ]

    form_values: Annotated[
        Nullable[Dict[str, DocumentFindFormValues]], pydantic.Field(alias="formValues")
    ]

    title: str

    created_at: Annotated[str, pydantic.Field(alias="createdAt")]

    updated_at: Annotated[str, pydantic.Field(alias="updatedAt")]

    completed_at: Annotated[Nullable[str], pydantic.Field(alias="completedAt")]

    deleted_at: Annotated[Nullable[str], pydantic.Field(alias="deletedAt")]

    team_id: Annotated[float, pydantic.Field(alias="teamId")]

    folder_id: Annotated[Nullable[str], pydantic.Field(alias="folderId")]

    use_legacy_field_insertion: Annotated[
        bool, pydantic.Field(alias="useLegacyFieldInsertion")
    ]

    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    internal_version: Annotated[float, pydantic.Field(alias="internalVersion")]

    user: DocumentFindUser

    recipients: List[DocumentFindRecipient]

    team: Nullable[DocumentFindTeam]

    document_data_id: Annotated[
        Optional[str], pydantic.Field(alias="documentDataId")
    ] = ""

    template_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="templateId")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["documentDataId", "templateId"]
        nullable_fields = [
            "externalId",
            "authOptions",
            "formValues",
            "completedAt",
            "deletedAt",
            "folderId",
            "templateId",
            "team",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class DocumentFindResponseTypedDict(TypedDict):
    r"""Successful response"""

    data: List[DocumentFindDataTypedDict]
    count: float
    current_page: float
    per_page: float
    total_pages: float


class DocumentFindResponse(BaseModel):
    r"""Successful response"""

    data: List[DocumentFindData]

    count: float

    current_page: Annotated[float, pydantic.Field(alias="currentPage")]

    per_page: Annotated[float, pydantic.Field(alias="perPage")]

    total_pages: Annotated[float, pydantic.Field(alias="totalPages")]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import BaseModel
import httpx
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class EmbeddingPresignCreateEmbeddingPresignTokenRequestTypedDict(TypedDict):
    expires_in: NotRequired[float]


class EmbeddingPresignCreateEmbeddingPresignTokenRequest(BaseModel):
    expires_in: Annotated[Optional[float], pydantic.Field(alias="expiresIn")] = 60


class EmbeddingPresignCreateEmbeddingPresignTokenInternalServerErrorIssueTypedDict(
    TypedDict
):
    message: str


class EmbeddingPresignCreateEmbeddingPresignTokenInternalServerErrorIssue(BaseModel):
    message: str


class EmbeddingPresignCreateEmbeddingPresignTokenInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[
        List[EmbeddingPresignCreateEmbeddingPresignTokenInternalServerErrorIssue]
    ] = None


@dataclass(unsafe_hash=True)
class EmbeddingPresignCreateEmbeddingPresignTokenInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: EmbeddingPresignCreateEmbeddingPresignTokenInternalServerErrorData = field(
        hash=False
    )

    def __init__(
        self,
        data: EmbeddingPresignCreateEmbeddingPresignTokenInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EmbeddingPresignCreateEmbeddingPresignTokenForbiddenIssueTypedDict(TypedDict):
    message: str


class EmbeddingPresignCreateEmbeddingPresignTokenForbiddenIssue(BaseModel):
    message: str


class EmbeddingPresignCreateEmbeddingPresignTokenForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[
        List[EmbeddingPresignCreateEmbeddingPresignTokenForbiddenIssue]
    ] = None


@dataclass(unsafe_hash=True)
class EmbeddingPresignCreateEmbeddingPresignTokenForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: EmbeddingPresignCreateEmbeddingPresignTokenForbiddenErrorData = field(
        hash=False
    )

    def __init__(
        self,
        data: EmbeddingPresignCreateEmbeddingPresignTokenForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EmbeddingPresignCreateEmbeddingPresignTokenUnauthorizedIssueTypedDict(TypedDict):
    message: str


class EmbeddingPresignCreateEmbeddingPresignTokenUnauthorizedIssue(BaseModel):
    message: str


class EmbeddingPresignCreateEmbeddingPresignTokenUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[
        List[EmbeddingPresignCreateEmbeddingPresignTokenUnauthorizedIssue]
    ] = None


@dataclass(unsafe_hash=True)
class EmbeddingPresignCreateEmbeddingPresignTokenUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: EmbeddingPresignCreateEmbeddingPresignTokenUnauthorizedErrorData = field(
        hash=False
    )

    def __init__(
        self,
        data: EmbeddingPresignCreateEmbeddingPresignTokenUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EmbeddingPresignCreateEmbeddingPresignTokenBadRequestIssueTypedDict(TypedDict):
    message: str


class EmbeddingPresignCreateEmbeddingPresignTokenBadRequestIssue(BaseModel):
    message: str


class EmbeddingPresignCreateEmbeddingPresignTokenBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[
        List[EmbeddingPresignCreateEmbeddingPresignTokenBadRequestIssue]
    ] = None


@dataclass(unsafe_hash=True)
class EmbeddingPresignCreateEmbeddingPresignTokenBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: EmbeddingPresignCreateEmbeddingPresignTokenBadRequestErrorData = field(
        hash=False
    )

    def __init__(
        self,
        data: EmbeddingPresignCreateEmbeddingPresignTokenBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EmbeddingPresignCreateEmbeddingPresignTokenResponseTypedDict(TypedDict):
    r"""Successful response"""

    token: str
    expires_at: str
    expires_in: float


class EmbeddingPresignCreateEmbeddingPresignTokenResponse(BaseModel):
    r"""Successful response"""

    token: str

    expires_at: Annotated[str, pydantic.Field(alias="expiresAt")]

    expires_in: Annotated[float, pydantic.Field(alias="expiresIn")]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import BaseModel
import httpx
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, TypedDict


class TemplateToggleTemplateDirectLinkRequestTypedDict(TypedDict):
    template_id: float
    enabled: bool


class TemplateToggleTemplateDirectLinkRequest(BaseModel):
    template_id: Annotated[float, pydantic.Field(alias="templateId")]

    enabled: bool


class TemplateToggleTemplateDirectLinkInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class TemplateToggleTemplateDirectLinkInternalServerErrorIssue(BaseModel):
    message: str


class TemplateToggleTemplateDirectLinkInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[TemplateToggleTemplateDirectLinkInternalServerErrorIssue]] = (
        None
    )


@dataclass(unsafe_hash=True)
class TemplateToggleTemplateDirectLinkInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: TemplateToggleTemplateDirectLinkInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: TemplateToggleTemplateDirectLinkInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class TemplateToggleTemplateDirectLinkForbiddenIssueTypedDict(TypedDict):
    message: str


class TemplateToggleTemplateDirectLinkForbiddenIssue(BaseModel):
    message: str


class TemplateToggleTemplateDirectLinkForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[TemplateToggleTemplateDirectLinkForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class TemplateToggleTemplateDirectLinkForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: TemplateToggleTemplateDirectLinkForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: TemplateToggleTemplateDirectLinkForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class TemplateToggleTemplateDirectLinkUnauthorizedIssueTypedDict(TypedDict):
    message: str


class TemplateToggleTemplateDirectLinkUnauthorizedIssue(BaseModel):
    message: str


class TemplateToggleTemplateDirectLinkUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[TemplateToggleTemplateDirectLinkUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class TemplateToggleTemplateDirectLinkUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: TemplateToggleTemplateDirectLinkUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: TemplateToggleTemplateDirectLinkUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class TemplateToggleTemplateDirectLinkBadRequestIssueTypedDict(TypedDict):
    message: str


class TemplateToggleTemplateDirectLinkBadRequestIssue(BaseModel):
    message: str


class TemplateToggleTemplateDirectLinkBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[TemplateToggleTemplateDirectLinkBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class TemplateToggleTemplateDirectLinkBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: TemplateToggleTemplateDirectLinkBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: TemplateToggleTemplateDirectLinkBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class TemplateToggleTemplateDirectLinkResponseTypedDict(TypedDict):
    r"""Successful response"""

    id: str
    token: str
    created_at: str
    enabled: bool
    direct_template_recipient_id: float
    envelope_id: str
    template_id: float


class TemplateToggleTemplateDirectLinkResponse(BaseModel):
    r"""Successful response"""

    id: str

    token: str

    created_at: Annotated[str, pydantic.Field(alias="createdAt")]

    enabled: bool

    direct_template_recipient_id: Annotated[
        float, pydantic.Field(alias="directTemplateRecipientId")
    ]

    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    template_id: Annotated[float, pydantic.Field(alias="templateId")]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from enum import Enum
import httpx
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class EnvelopeDistributeDateFormat(str, Enum):
    YYYY_M_MDD_HH_MM_A = "yyyy-MM-dd hh:mm a"
    YYYY_M_MDD = "yyyy-MM-dd"
    DD_MM_SLASH_YYYY = "dd/MM/yyyy"
    MM_DD_SLASH_YYYY = "MM/dd/yyyy"
    YY_M_MDD = "yy-MM-dd"
    MMMM_DD_COMMA_YYYY = "MMMM dd, yyyy"
    EEEE_MMMM_DD_COMMA_YYYY = "EEEE, MMMM dd, yyyy"
    DD_MM_SLASH_YYYY_HH_MM_A = "dd/MM/yyyy hh:mm a"
    DD_MM_SLASH_YYYY_H_HMM = "dd/MM/yyyy HH:mm"
    MM_DD_SLASH_YYYY_HH_MM_A = "MM/dd/yyyy hh:mm a"
    MM_DD_SLASH_YYYY_H_HMM = "MM/dd/yyyy HH:mm"
    DD_DOT_MM_DOT_YYYY = "dd.MM.yyyy"
    DD_DOT_MM_DOT_YYYY_H_HMM = "dd.MM.yyyy HH:mm"
    YYYY_M_MDD_H_HMM = "yyyy-MM-dd HH:mm"
    YY_M_MDD_HH_MM_A = "yy-MM-dd hh:mm a"
    YY_M_MDD_H_HMM = "yy-MM-dd HH:mm"
    YYYY_M_MDD_H_HMMSS = "yyyy-MM-dd HH:mm:ss"
    MMMM_DD_COMMA_YYYY_HH_MM_A = "MMMM dd, yyyy hh:mm a"
    MMMM_DD_COMMA_YYYY_H_HMM = "MMMM dd, yyyy HH:mm"
    EEEE_MMMM_DD_COMMA_YYYY_HH_MM_A = "EEEE, MMMM dd, yyyy hh:mm a"
    EEEE_MMMM_DD_COMMA_YYYY_H_HMM = "EEEE, MMMM dd, yyyy HH:mm"
    ISO8601_FULL = "yyyy-MM-dd'T'HH:mm:ss.SSSXXX"


class EnvelopeDistributeDistributionMethod(str, Enum):
    EMAIL = "EMAIL"
    NONE = "NONE"


class EnvelopeDistributeLanguage(str, Enum):
    DE = "de"
    EN = "en"
    FR = "fr"
    ES = "es"
    IT = "it"
    PL = "pl"


class EnvelopeDistributeEmailSettingsTypedDict(TypedDict):
    recipient_signing_request: NotRequired[bool]
    recipient_removed: NotRequired[bool]
    recipient_signed: NotRequired[bool]
    document_pending: NotRequired[bool]
    document_completed: NotRequired[bool]
    document_deleted: NotRequired[bool]
    owner_document_completed: NotRequired[bool]


class EnvelopeDistributeEmailSettings(BaseModel):
    recipient_signing_request: Annotated[
        Optional[bool], pydantic.Field(alias="recipientSigningRequest")
    ] = True

    recipient_removed: Annotated[
        Optional[bool], pydantic.Field(alias="recipientRemoved")
    ] = True

    recipient_signed: Annotated[
        Optional[bool], pydantic.Field(alias="recipientSigned")
    ] = True

    document_pending: Annotated[
        Optional[bool], pydantic.Field(alias="documentPending")
    ] = True

    document_completed: Annotated[
        Optional[bool], pydantic.Field(alias="documentCompleted")
    ] = True

    document_deleted: Annotated[
        Optional[bool], pydantic.Field(alias="documentDeleted")
    ] = True

    owner_document_completed: Annotated[
        Optional[bool], pydantic.Field(alias="ownerDocumentCompleted")
    ] = True


class EnvelopeDistributeMetaTypedDict(TypedDict):
    subject: NotRequired[str]
    message: NotRequired[str]
    timezone: NotRequired[str]
    date_format: NotRequired[EnvelopeDistributeDateFormat]
    distribution_method: NotRequired[EnvelopeDistributeDistributionMethod]
    redirect_url: NotRequired[str]
    language: NotRequired[EnvelopeDistributeLanguage]
    email_id: NotRequired[Nullable[str]]
    email_reply_to: NotRequired[Nullable[str]]
    email_settings: NotRequired[Nullable[EnvelopeDistributeEmailSettingsTypedDict]]


class EnvelopeDistributeMeta(BaseModel):
    subject: Optional[str] = None

    message: Optional[str] = None

    timezone: Optional[str] = None

    date_format: Annotated[
        Optional[EnvelopeDistributeDateFormat], pydantic.Field(alias="dateFormat")
    ] = None

    distribution_method: Annotated[
        Optional[EnvelopeDistributeDistributionMethod],
        pydantic.Field(alias="distributionMethod"),
    ] = None

    redirect_url: Annotated[Optional[str], pydantic.Field(alias="redirectUrl")] = None

    language: Optional[EnvelopeDistributeLanguage] = None

    email_id: Annotated[OptionalNullable[str], pydantic.Field(alias="emailId")] = UNSET

    email_reply_to: Annotated[
        OptionalNullable[str], pydantic.Field(alias="emailReplyTo")
    ] = UNSET

    email_settings: Annotated[
        OptionalNullable[EnvelopeDistributeEmailSettings],
        pydantic.Field(alias="emailSettings"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "subject",
            "message",
            "timezone",
            "dateFormat",
            "distributionMethod",
            "redirectUrl",
            "language",
            "emailId",
            "emailReplyTo",
            "emailSettings",
        ]
        nullable_fields = ["emailId", "emailReplyTo", "emailSettings"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class EnvelopeDistributeRequestTypedDict(TypedDict):
    envelope_id: str
    meta: NotRequired[EnvelopeDistributeMetaTypedDict]


class EnvelopeDistributeRequest(BaseModel):
    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    meta: Optional[EnvelopeDistributeMeta] = None


class EnvelopeDistributeInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class EnvelopeDistributeInternalServerErrorIssue(BaseModel):
    message: str


class EnvelopeDistributeInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeDistributeInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeDistributeInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: EnvelopeDistributeInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeDistributeInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeDistributeForbiddenIssueTypedDict(TypedDict):
    message: str


class EnvelopeDistributeForbiddenIssue(BaseModel):
    message: str


class EnvelopeDistributeForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeDistributeForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeDistributeForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: EnvelopeDistributeForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeDistributeForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeDistributeUnauthorizedIssueTypedDict(TypedDict):
    message: str


class EnvelopeDistributeUnauthorizedIssue(BaseModel):
    message: str


class EnvelopeDistributeUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeDistributeUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeDistributeUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: EnvelopeDistributeUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeDistributeUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeDistributeBadRequestIssueTypedDict(TypedDict):
    message: str


class EnvelopeDistributeBadRequestIssue(BaseModel):
    message: str


class EnvelopeDistributeBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeDistributeBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeDistributeBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: EnvelopeDistributeBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeDistributeBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeDistributeResponseTypedDict(TypedDict):
    r"""Successful response"""

    success: bool


class EnvelopeDistributeResponse(BaseModel):
    r"""Successful response"""

    success: bool
